// Ribbon theme for Shower HTML presentation template: github.com/pepelsbey/shower
// Copyright © 2010–2012 Vadim Makeev, pepelsbey.net
// Licensed under MIT license: github.com/pepelsbey/shower/wiki/License-En

// Layout
$width:1024px; // Slide width, permanent in most cases
$height:768px; // Slide height, 640px for 16/10, 768px for 4/3
$top:10px;     // Top padding above slide content
$sides:120px;  // Left and right paddings around slide content
$break:1324px; // Window width for small thumbnails to appear
$grid:'';

// Mixins
@mixin tab-size($n) {
	-moz-tab-size:$n;
	-o-tab-size:$n;
	tab-size:$n;
	}
@mixin transform($n) {
	-webkit-transform:$n;
	-moz-transform:$n;
	-ms-transform:$n;
	-o-transform:$n;
	transform:$n;
	}
@mixin transform-origin($n) {
	-webkit-transform-origin:$n;
	-moz-transform-origin:$n;
	-ms-transform-origin:$n;
	-o-transform-origin:$n;
	transform-origin:$n;
	}
@mixin transition($n) {
	-webkit-transition:$n;
	-moz-transition:$n;
	-o-transition:$n;
	transition:$n;
	}
